PyWin32 Compatibility Layer
===========================

The win32ctypes library provides a compatibility layer with
PyWin32. We attempt to keep the signature of the Functions and their
behaviour as close as possible to PyWin32. For details and behaviour
please refer to the Pywin32 documentation and the related
`MSDN <https://msdn.microsoft.com>`_ reference pages.


.. autosummary::
   :toctree: api
   :template: module_template.rst

   win32ctypes.pywin32.win32api
   win32ctypes.pywin32.win32cred
   win32ctypes.pywin32.pywintypes
